<?php

require_once('includes/lib/base/core-class.php');
require_once('rift-slider-plugin.php');

/**
 * Initialize class.
 */
if (!class_exists('initialize')) {

    class initialize {

        private $_core;
        private $_plugin;

        /**
         * The Initialize constructor.
         * 
         * @param type $plugin_name
         * @param type $plugin_text_domain
         * @param type $plugin_option_prefix
         * @param type $plugin_version
         */
        public function __construct($plugin_name, $plugin_text_domain, $plugin_option_prefix, $plugin_version) {

            $this->_core = new core();
            $this->_plugin = new rift_slider_plugin($plugin_name, $plugin_text_domain, $plugin_option_prefix, $plugin_version);
        }

        /**
         * The activate function is called when the plugin is activated.
         * @return void
         */
        public function activate() {

            $this->_core->set_php_version('5.3');

            // Next, run the version check.
            // If it is successful, continue with initialization for this plugin
            if ($this->_core->php_version_check()) {

                if (!$this->_plugin->is_installed()) {
                    $this->_plugin->activate();
                } else {
                    // Perform any version-upgrade activities prior to activation (e.g. database changes)
                    $this->_plugin->upgrade();
                }
            }
        }

        /**
         * The deactivate function is called when the plugin is deactivated.
         * @return void
         */
        public function deactivate() {

            if ($this->_plugin->is_installed()) {
                $this->_plugin->deactivate();

                // Register the Plugin Uninstall Hook
                register_uninstall_hook(__FILE__, array(&$synth_rift_slider_initialize, 'uninstall'));
            }
        }

        /**
         * This function will run on every web request.  Keep this function
         * as slim-lined as possible for effecient execution.
         * @return void
         */
        public function run() {

            //check if the plugin is installed before running
            if ($this->_plugin->is_installed()) {

                //initialize any scripts
                $this->_plugin->frontend_scripts();

                //add callbacks to hooks            
                $this->_plugin->add_actions_and_filters();
            }
        }

    }

}
?>